@@ -273,11 +273,6 @@ def pickle_load(filename: Union[str, Path]) -> Any:
         return pickle.load(ifile)
 
 
-def pickle_dump(obj: Any, filename: Union[str, Path]) -> None:
-    with open(filename, "wb") as ofile:
-        pickle.dump(obj, ofile, pickle.HIGHEST_PROTOCOL)
-
-
 def cloudpickle_dump(obj: Any, filename: Union[str, Path]) -> None:
     with open(filename, "wb") as ofile:
         cloudpickle.dump(obj, ofile, pickle.HIGHEST_PROTOCOL)
