@@ -398,7 +398,9 @@ def _make_sbatch_string(
     gpus_per_node: tp.Optional[int] = None,
     gpus_per_task: tp.Optional[int] = None,
     setup: tp.Optional[tp.List[str]] = None,
-    mem: str = "64GB",
+    mem: tp.Optional[str] = None,
+    mem_per_gpu: tp.Optional[str] = None,
+    mem_per_cpu: tp.Optional[str] = None,
     signal_delay_s: int = 90,
     comment: str = "",
     constraint: str = "",
